from flask import (current_app)


class APIBaseError(Exception):
    status_code = None
    error = None
    error_description = None

    def __init__(self, error_description=None, error=None,
                 status_code=None, errors=None):
        Exception.__init__(self)

        if status_code is not None:
            self.status_code = status_code
        if error is not None:
            self.error = error
        if error_description is not None:
            self.error_description = error_description

        self.errors = errors or []
        if current_app:
            current_app.logger.error(
                '{} {} - {}'.format(
                    self.status_code,
                    self.error or '',
                    self.error_description or ''))

    def to_dict(self):
        return {
            'error': self.error,
            'error_description': self.error_description,
            'errors': self.errors
        }


class BadRequestError(APIBaseError):
    status_code = 400
    error = 'bad_request'


class InternalServerError(APIBaseError):
    status_code = 500
    error = 'internal_server_error'


class UnauthorizedError(APIBaseError):
    status_code = 401
    error = 'not_authorized'


class ForbiddenError(APIBaseError):
    status_code = 403
    error = 'permission_denied'


class NotFoundError(APIBaseError):
    status_code = 404
    error = 'not_found'


class MethodNotAllowedError(APIBaseError):
    status_code = 405
    error = 'method_not_allowed'


class UnsupportedMediaError(APIBaseError):
    status_code = 415
    error = 'unsupported_media_type'
    error_description = 'Request is in an invalid format'


class ValidationError(APIBaseError):
    status_code = 422
    error = 'unprocessable_entity'
    error_description = 'Data Validation Error'


class NotImplementedError(APIBaseError):
    status_code = 501
    error = 'not_implemented'
    error_description = ('The server does not support the functionality '
                         'required to fulfill this request')


class ServiceUnavailableError(APIBaseError):
    status_code = 503
    error = 'service_unavailable'


class GatewayTimeout(APIBaseError):
    status_code = 504
    error = 'gateway_timeout'


class CredentialDeletedError(BadRequestError):
    error = 'credential_deleted'


class ConflictError(APIBaseError):
    status_code = 409
    error = 'conflict'


class ResourceExistsError(ConflictError):
    error_description = 'Attempt to create a resource that already exists.'
