from uuid import uuid4
import json

from globus.manager.api.models import db
from globus.manager.api.models.base import Base


class Collection(Base):
    __tablename__ = 'collection'

    id = db.Column(db.TEXT, primary_key=True)
    path = db.Column(db.TEXT)
    domain = db.Column(db.TEXT)
    _collection_policies = db.Column('collection_policies', db.TEXT)
    user_credential_id = db.Column(db.TEXT,
                                   db.ForeignKey('user_credential.id'),
                                   nullable=False)

    user_credential = db.relationship('UserCredential',
                                      foreign_keys=[user_credential_id],
                                      uselist=False,
                                      lazy='joined')

    def __init__(self, **kwargs):
        super(Collection, self).__init__(**kwargs)

        if 'id' not in kwargs:
            self.id = str(uuid4())

        for k, v in kwargs.items():
            setattr(self, k, v)

    @property
    def collection_policies(self):
        if self._collection_policies is None:
            return None

        return json.loads(self._collection_policies)

    @collection_policies.setter
    def collection_policies(self, collection_policies):
        try:
            self._collection_policies = json.dumps(collection_policies)
        except ValueError:
            raise ValueError(
                '{}.collection_policies must be a JSON-encodable object'.
                format(
                    self.__class__.__name__))

    def __repr__(self):
        return '<Collection {}>'.format(self.id)
