import arrow
from datetime import datetime

from sqlalchemy_utils import ArrowType

from globus.manager.api.models import db


def ensure_arrowtime(value):
    """
    Ensure that `value` is a datetime or Arrow object and that it
    is carrying tzinfo.
    """
    if value is not None:
        if (isinstance(value, (datetime, arrow.Arrow)) and
                value.tzinfo is None):
            raise ValueError("{!r} must be TZ-aware".format(value))
        return arrow.get(value).to('UTC')
    return value


class UTCArrowType(ArrowType):
    """
    Custom SQLAlchemy datatype that extends ArrowType
    to be include timezone support.
    """
    impl = db.DateTime(timezone=True)

    def process_bind_param(self, value, dialect):
        arrowtime = ensure_arrowtime(value)
        if arrowtime is not None:
            return arrowtime.datetime
        return None
