import json

from uuid import uuid4

from globus.manager.api.models import db
from globus.manager.api.models.base import Base


class StorageGateway(Base):
    __tablename__ = 'storage_gateway'

    id = db.Column(db.TEXT, primary_key=True)
    display_name = db.Column(db.TEXT, nullable=False, unique=True)
    _credential = db.Column('credential', db.TEXT)
    _storage_policies = db.Column('storage_policies', db.TEXT)
    allow_guest_collections = db.Column(
        db.BOOLEAN, nullable=False, server_default='0')
    allow_mapped_collections = db.Column(
        db.BOOLEAN, nullable=False, server_default='0')
    require_high_assurance = db.Column(
        db.BOOLEAN, nullable=False, server_default='0')
    deleted = db.Column(
        db.Boolean, nullable=False, index=True, server_default='0')

    connector_id = db.Column(db.TEXT,
                             db.ForeignKey('connector.id'),
                             nullable=False)

    connector = db.relationship('Connector',
                                foreign_keys=[connector_id],
                                uselist=False,
                                lazy='joined')

    @property
    def credential(self):
        if self._credential is None:
            return None

        return json.loads(self._credential)

    @credential.setter
    def credential(self, credential):
        try:
            self._credential = json.dumps(credential)
        except ValueError:
            raise ValueError(
                '{}.credential must be a JSON-encodable object'.format(
                    self.__class__.__name__))

    @property
    def storage_policies(self):
        if self._storage_policies is None:
            return None

        return json.loads(self._storage_policies)

    @storage_policies.setter
    def storage_policies(self, storage_policies):
        try:
            self._storage_policies = json.dumps(storage_policies)
        except ValueError:
            raise ValueError(
                '{}.storage_policies must be a JSON-encodable object'.format(
                    self.__class__.__name__))

    def __init__(self, **kwargs):
        super(StorageGateway, self).__init__(**kwargs)

        if 'id' not in kwargs:
            self.id = str(uuid4())

        for k, v in kwargs.items():
            setattr(self, k, v)

    def __repr__(self):
        return '<StorageGateway {}>'.format(self.display_name)
