import json

from uuid import uuid4

from globus.manager.api.models import db
from globus.manager.api.models.base import Base


class UserCredential(Base):
    __tablename__ = 'user_credential'
    __table_args__ = (
        db.UniqueConstraint('storage_gateway_id',
                            'storage_gateway_user_id',
                            'identity_id'),
    )

    id = db.Column(db.TEXT, primary_key=True)
    display_name = db.Column(db.TEXT)
    identity_id = db.Column(db.TEXT, nullable=False, index=True)
    _storage_credential = db.Column('storage_credential', db.TEXT)

    storage_gateway_user_id = db.Column(db.TEXT, nullable=False, index=True)

    deleted = db.Column(
        db.Boolean, nullable=False, index=True, server_default='0')

    invalid = db.Column(
        db.Boolean, nullable=False, index=True, server_default='0')

    storage_gateway_id = db.Column(db.TEXT,
                                   db.ForeignKey('storage_gateway.id'),
                                   nullable=False)

    storage_gateway = db.relationship('StorageGateway',
                                      foreign_keys=[storage_gateway_id],
                                      uselist=False,
                                      lazy='joined')

    @property
    def storage_credential(self):
        if self._storage_credential is None:
            return None

        return json.loads(self._storage_credential)

    @storage_credential.setter
    def storage_credential(self, storage_credential):
        try:
            self._storage_credential = json.dumps(storage_credential)
        except ValueError:
            raise ValueError(
                '{}.storage_credential must be a JSON-encodable object'.format(
                    self.__class__.__name__))

    def __init__(self, **kwargs):
        super(UserCredential, self).__init__(**kwargs)

        if 'id' not in kwargs:
            self.id = str(uuid4())

        for k, v in kwargs.items():
            setattr(self, k, v)

    def __repr__(self):
        return '<UserCredential {}>'.format(self.id)
