import os
import pkgutil

from globus.manager.version import __version__ as VERSION


class HTTPSEndpoint(object):
    __etc_httpd = os.path.expanduser('~gcsweb/etc/httpd/conf.d')

    def __init__(self, client_id, parent_client_id, secret,
                 domain, collection_type='guest', required_domain=None,
                 collection_flags='', environment='production',
                 authentication_assurance_timeout=None):
        environment = environment.lower()
        self.client_id = client_id
        self.parent_client_id = parent_client_id
        self.secret = secret
        self.domain = domain
        self.collection_type = collection_type
        self.conf_file = os.path.join(
            self.__etc_httpd, '{client_id}.conf'.format(
                client_id=self.client_id))
        self.required_domain = ''
        self.collection_flags = ''
        self.define_require_high_assurance = ''
        self.authentication_assurance_timeout = ''

        if authentication_assurance_timeout is not None:
            self.authentication_assurance_timeout = (
                'GlobusAuthenticationAssuranceTimeout {}'.format(
                    authentication_assurance_timeout))
        if required_domain is not None:
            self.required_domain = 'GlobusRequiredUserDomain    {}'.format(
                required_domain)
        if collection_flags != '':
            self.collection_flags = 'GlobusCollectionFlags       {}'.format(
                collection_flags)

        if 'RequireHighAssurance' in collection_flags.split('|'):
            self.define_require_high_assurance = (
                'Define GLOBUS_HIGH_ASSURANCE')

        if environment == 'production':
            self.auth_endpoint = 'https://auth.globus.org'
            self.transfer_endpoint = 'https://transfer.api.globus.org'
        elif environment == 'preview':
            self.auth_endpoint = 'https://auth.preview.globus.org'
            self.transfer_endpoint = 'https://transfer.api.preview.globus.org'
        else:
            self.auth_endpoint = (
                'https://auth.{environment}.globuscs.info'.format(
                    environment=environment))
            self.transfer_endpoint = (
                'https://transfer.{environment}.api.globusonline.org'.format(
                    environment=environment))

    def setup(self):
        https_template = pkgutil.get_data(
            'globus.manager.api.utils',
            'vhost-https-endpoint.conf').decode('ascii')

        with open(self.conf_file, 'w') as f:
            f.write(https_template.format(
                config_version=VERSION,
                client_id=self.client_id,
                secret=self.secret,
                domain=self.domain,
                auth_endpoint=self.auth_endpoint,
                transfer_endpoint=self.transfer_endpoint,
                globus_required_domain=self.required_domain,
                define_require_high_assurance=(
                    self.define_require_high_assurance),
                globus_collection_flags=self.collection_flags,
                collection_type=self.collection_type,
                authentication_assurance_timeout=(
                    self.authentication_assurance_timeout)))

    def cleanup(self):
        if os.path.exists(self.conf_file):
            os.path.remove(self.conf_file)
