"""
Provides helpers for creating clients for the transfer and dns services

These functions must be called within an app context with valid Configuration
unless all optional arguments are given
"""
import os
import globus_sdk

from globus.manager.api.models import Configuration
from globus.manager.api.utils.dns_client import DnsClient

DNS_SCOPE = 'https://auth.globus.org/scopes/glob.us/manage_dns'
TRANSFER_SCOPE = 'urn:globus:auth:scope:transfer.api.globus.org:all'


def _set_sdk_env(environment=None):
    if not environment:
        environment = Configuration.query.filter_by(
            name='environment').one().value
    os.environ['GLOBUS_SDK_ENVIRONMENT'] = environment.lower()


def _get_internal_client():
    client_id = Configuration.query.filter_by(
        name='client_id').one().value
    client_secret = Configuration.query.filter_by(
        name='client_secret').one().value

    return globus_sdk.ConfidentialAppAuthClient(client_id, client_secret)


def get_transfer_client(authorizer=None, environment=None):
    _set_sdk_env(environment)

    if not authorizer:
        authorizer = globus_sdk.ClientCredentialsAuthorizer(
            _get_internal_client(), TRANSFER_SCOPE)

    return globus_sdk.TransferClient(authorizer=authorizer)


def get_dns_client(authorizer=None, environment=None):
    _set_sdk_env(environment)

    if not authorizer:
        authorizer = globus_sdk.ClientCredentialsAuthorizer(
            _get_internal_client(), DNS_SCOPE)

    return DnsClient(authorizer=authorizer)
