from flask_migrate import Migrate

from globus.manager.api import make_app
from globus.manager.api.models import db, Configuration
from globus.manager.api.schemas import ma

app = make_app()
db.init_app(app)
migrate = Migrate(app, db)
ma.init_app(app)

# As a convenience, so we can use `flask.current_app`, load the
# Globus Auth client credentials and host endpoint id
# into the app's runtime config.
with app.app_context():
    globus_client_id = Configuration.query.filter_by(
        name='client_id').one().value
    globus_client_secret = Configuration.query.filter_by(
        name='client_secret').one().value
    host_endpoint_id = Configuration.query.filter_by(
        name='host_endpoint_id').one().value

app.config['CLIENT_ID'] = globus_client_id
app.config['CLIENT_SECRET'] = globus_client_secret
app.config['HOST_ENDPOINT_ID'] = host_endpoint_id

if __name__ == '__main__':
    app.run(debug=True, host='localhost',
            ssl_context=('./ssl/server.crt', './ssl/server.key'))
