import os
import time

import dns.resolver
from globus.manager.api import make_app
from globus.manager.api.models import db
from globus.manager.api.schemas import ma
from globus.manager.api.utils.services import get_dns_client

os.environ['MANAGER_CONFIG'] = 'config/production.py'

app = make_app()
db.init_app(app)
ma.init_app(app)


def auth_hook():
    certbot_domain = os.environ['CERTBOT_DOMAIN']
    certbot_validation = os.environ['CERTBOT_VALIDATION']

    with app.app_context():
        dns_client = get_dns_client()
        dns_client.create_txt(
            certbot_domain,
            certbot_validation)

        resolver = dns.resolver.Resolver()
        record = '_acme-challenge.{}'.format(certbot_domain)
        while True:
            try:
                answers = resolver.query(record, 'TXT')
                for rdata in answers:
                    for txt_string in rdata.strings:
                        txt_string = txt_string.decode('utf8')
                        if txt_string == certbot_validation:
                            return
            except dns.resolver.NXDOMAIN:
                pass
            time.sleep(30)
