import click
from globus.manager.api.models import (
    Collection,
    Configuration,
    PreallocatedCollection,
)
from globus.manager.api.utils.https_endpoint import HTTPSEndpoint
from globus.manager.version import __version__
from ..app import app
import sqlalchemy


@click.command(
    name='rewrite-https-config',
    short_help='Rewrite the https config for a GCSv5 collection',
    help='''\
The collection rewrite-https-config subcommand updates the https config
file for a collection.''')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-setup')
@click.option(
    '--preallocated-collections', '-p',
    is_flag=True,
    help='Update the preallocated collections as well')
@click.argument('collection-id', required=False)
@click.pass_context
def collection_rewrite_https_config(
        ctx, preallocated_collections, collection_id):
    with app.app_context():
        try:
            environment = Configuration.query.filter_by(
                name='environment').one().value
            client_id = Configuration.query.filter_by(
                name='client_id').one().value
            client_secret = Configuration.query.filter_by(
                name='client_secret').one().value
            for c in Configuration.query.all():
                app.config[c.name.upper()] = c.value
        except sqlalchemy.exc.OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)
        except sqlalchemy.orm.exc.NoResultFound:
            click.echo(
                "Endpoint not configured propertly. Please run "
                "globus-connect-server-setup")
            ctx.exit(1)

        try:
            if collection_id is not None:
                q = Collection.query.filter_by(id=collection_id)
            else:
                q = Collection.query
            for c in q.all():
                if c.domain is None:
                    continue
                sg = c.user_credential.storage_gateway
                sp = c.user_credential.storage_gateway.storage_policies
                collection_type = c.collection_policies.get(
                    'public', {}).get('type')
                if sg.require_high_assurance:
                    required_domain = sp.get('public', {}).get(
                        'domains')[0]
                    timeout = sp.get(
                        'public', {}).get('authentication_assurance_timeout')
                    h = HTTPSEndpoint(
                        c.id, client_id,
                        client_secret, c.domain,
                        collection_type=collection_type,
                        required_domain=required_domain,
                        collection_flags='RequireHighAssurance',
                        environment=environment.lower(),
                        authentication_assurance_timeout=timeout)
                else:
                    required_domain = sp.get('public', {}).get(
                        'domains', [None])[0]
                    h = HTTPSEndpoint(
                        c.id, client_id,
                        client_secret, c.domain,
                        collection_type=collection_type,
                        required_domain=required_domain,
                        environment=environment.lower())
                h.setup()

            if preallocated_collections:
                for pc in PreallocatedCollection.query.all():
                    if pc.domain is None:
                        continue
                    h = HTTPSEndpoint(
                        pc.id, client_id,
                        client_secret, pc.domain,
                        environment=environment.lower())
                    h.setup()

        except sqlalchemy.exc.OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)


if __name__ == '__main__':
    collection_rewrite_https_config()
