import os

import click
import globus_sdk

from ...app import app
from globus.manager.api.utils.services import get_transfer_client
from globus.manager.api.models import Configuration
from globus.manager.version import __version__
import sqlalchemy.exc

VIEW_IDENTITIES_SCOPE = 'urn:globus:auth:scope:auth.globus.org:view_identities'


@click.command(
    'show',
    short_help='Show the admin roles assigned on a Globus Connect Server '
               'endpoint',
    help='Show the admin roles assigned on a Globus Connect Server endpoint')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.pass_context
def endpoint_admin_show(ctx):
    with app.app_context():
        try:
            globus_client_id = Configuration.query.filter_by(
                name='client_id').one().value
            globus_client_secret = Configuration.query.filter_by(
                name='client_secret').one().value
            host_endpoint_id = Configuration.query.filter_by(
                name='host_endpoint_id').one().value
            globus_sdk_environment = Configuration.query.filter_by(
                name='environment').one().value.lower()
            os.environ['GLOBUS_SDK_ENVIRONMENT'] = globus_sdk_environment

            client = globus_sdk.ConfidentialAppAuthClient(
                globus_client_id, globus_client_secret)
            tokens = client.oauth2_client_credentials_tokens(
                requested_scopes=VIEW_IDENTITIES_SCOPE).by_resource_server
            auth_token = tokens['auth.globus.org']['access_token']
            auth_client = globus_sdk.AuthClient(
                authorizer=globus_sdk.AccessTokenAuthorizer(auth_token))

            transfer_client = get_transfer_client()

            click.echo('Role | Type | Name')
            role_list = transfer_client.endpoint_role_list(host_endpoint_id)
            for r in role_list:
                ids = auth_client.get_identities(ids=r['principal']).data

                click.echo(
                    '{} | {} | {}'.format(
                        r['role'],
                        r['principal_type'],
                        ids['identities'][0]['username']))
        except globus_sdk.exc.TransferAPIError as e:
            click.echo(str(e))
            ctx.exit(1)
        except sqlalchemy.exc.OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)
