import click

from ...app import app
from globus.manager.api.models import Configuration
from globus.manager.version import __version__
import sqlalchemy.exc
import sqlalchemy.orm.exc


@click.command(
    'get',
    short_help='Get a configuration option on a Globus Connect Server '
               'endpoint',
    help='Get a configuration option on a Globus Connect Server endpoint')
@click.option(
    '--client-id', '-i',
    is_flag=True,
    help='Globus Client ID')
@click.option(
    '--client-secret', '-s',
    is_flag=True,
    help='Globus Client Secret')
@click.option(
    '--server-name', '-n',
    is_flag=True,
    help='Endpoint glob.us domain name')
@click.option(
    '--name', '-N',
    help='Configuration option name')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.pass_context
def endpoint_configuration_get(
        ctx, client_id, client_secret, server_name, name):
    def get(n):
        try:
            conf = Configuration.query.filter_by(name=n).one()
            click.echo('{} | {}'.format(n, conf.value))
        except sqlalchemy.orm.exc.NoResultFound:
            pass

    with app.app_context():
        try:
            click.echo('Name | Value')
            if client_id:
                get('client_id')
            if client_secret is not None:
                get('client_secret')
            if server_name is not None:
                get('server_name')
            if name is not None:
                get(name)
        except sqlalchemy.exc.OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)
