import click

from ...app import app, db
from globus.manager.api.models import Configuration
from globus.manager.version import __version__
import sqlalchemy.exc
import sqlalchemy.orm.exc


@click.command(
    'set',
    short_help='Set a configuration value on a '
               'Globus Connect Server endpoint',
    help='Set a configuration value on a Globus Connect Server endpoint')
@click.option(
    '--client-id', '-i',
    help='Globus Client ID')
@click.option(
    '--client-secret', '-s',
    help='Globus Client Secret')
@click.option(
    '--server-name', '-n',
    help='Endpoint glob.us domain name')
@click.option(
    '--name', '-N',
    help='Configuration option name')
@click.option(
    '--value', '-V',
    help='Configuration option value')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.pass_context
def endpoint_configuration_set(
        ctx, client_id, client_secret, server_name, name, value):
    def add_or_update(n, v):
        try:
            conf = Configuration.query.filter_by(name=n).one()
            conf.value = v
        except sqlalchemy.orm.exc.NoResultFound:
            conf = Configuration(name=n, value=v)
        db.session.add(conf)

    with app.app_context():
        try:
            if client_id is not None:
                add_or_update('client_id', client_id)
            if client_secret is not None:
                add_or_update('client_secret', client_secret)
            if server_name is not None:
                add_or_update('server_name', server_name)
            if name is not None and value is not None:
                add_or_update(name, value)
            if (client_id is None
                    and client_secret is None
                    and server_name is None
                    and name is None):
                name = click.prompt('Name')
                value = click.prompt('Value')
                add_or_update(name, value)
            db.session.commit()
        except sqlalchemy.exc.OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)
