import os
import pkgutil

import click

from globus_gcs import GCSManager, WebServerManager
from globus.manager.version import __version__


@click.command(
    'rewrite-https-config',
    help='Update the GCS Manager HTTPS configuration')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.pass_context
def endpoint_rewrite_https_config(ctx):
    vhost_template = pkgutil.get_data(
        'globus_gcs.apache',
        'vhost-gcs-manager.conf').decode('ascii')

    if os.path.exists("/var/lib/globus-connect-server/dns-name.txt"):
        with open("/var/lib/globus-connect-server/dns-name.txt", "r") as f:
            domain = f.read().strip()
        if domain != "":
            domain_cred_dir = os.path.join(
                os.path.expanduser('~gcsweb/etc/letsencrypt/live'),
                domain)
            certificate_file = os.path.join(domain_cred_dir, 'cert.pem')
            key_file = os.path.join(domain_cred_dir, 'privkey.pem')
            chain_file = os.path.join(domain_cred_dir, 'chain.pem')

            vhost_config = vhost_template.format(
                GCS_MANAGER_SERVER=domain,
                GCS_MANAGER_CERTIFICATE=certificate_file,
                GCS_MANAGER_KEY=key_file,
                GCS_MANAGER_CHAIN=chain_file)
            WebServerManager.site_add(
                GCSManager.service_name,
                vhost_config,
                enable=True)
        else:
            click.echo("Domain not configured, nothing to do")
    else:
        click.echo("Domain not configured, nothing to do")
