import click
from globus_sdk import GlobusAPIError

from ..app import app
from globus.manager.api.models import Configuration
from globus.manager.api.utils.services import get_dns_client
from globus.manager.version import __version__


@click.command(
    'update',
    short_help='Update information about the Globus Connect Server endpoint',
    help='Update information about the Globus Connect Server endpoint')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.option('--host', help="update the public hostname the endpoint's "
                             "glob.us domain name directs to.")
@click.pass_context
def endpoint_update(ctx, host):
    with app.app_context():

        if host:
            try:
                dns_client = get_dns_client()
                domain = Configuration.query.filter_by(
                    name='server_name').one().value
                dns_client.update_domain(domain, cname=host)
                click.echo("Updated domain {} to redirect to {}".format(
                    domain, host))

            except GlobusAPIError as e:
                click.echo(str(e).strip())
                ctx.exit(1)

        else:
            click.echo("Nothing to update")
            ctx.exit(1)
