import click
import globus_sdk
import sqlalchemy.orm.exc

from globus.manager.api.utils.services import get_transfer_client
from ..collection.delete import collection_delete
from ..app import app, db
from globus.manager.api.models import (
    Collection,
    StorageGateway,
    UserCredential
)
from globus.manager.version import __version__
from sqlalchemy.exc import OperationalError


@click.command(name='delete', help='Delete a storage gateway')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.argument('STORAGE_GATEWAY_ID', required=False)
@click.pass_context
def storage_gateway_delete(ctx, storage_gateway_id):
    with app.app_context():
        try:
            transfer_client = get_transfer_client()
        except OperationalError:
            click.echo('Permission denied')
            ctx.exit(1)

        ss = None
        try:
            ss = StorageGateway.query.filter_by(id=storage_gateway_id).one()
        except sqlalchemy.orm.exc.NoResultFound:
            click.echo('No such storage gateway.')

        if ss is not None:
            in_use_prompted = False
            all_user_credentials_deleted = True
            for uc in UserCredential.query.filter_by(storage_gateway_id=ss.id):
                all_collections_deleted = True
                for c in Collection.query.filter_by(user_credential_id=uc.id):
                    endpoint_name = '[deleted]'
                    if not in_use_prompted:
                        click.echo('Storage System {0} in use'.format(ss.id))
                        in_use_prompted = True
                    try:
                        endpoint = transfer_client.get_endpoint(c.id)
                        endpoint_name = endpoint.data['display_name']
                    except globus_sdk.exc.TransferAPIError as e:
                        if e.http_status != 404:
                            raise e

                    prompt = 'Delete collection {0}'.format(c.id)
                    if endpoint_name != '':
                        prompt = 'Delete collection "{0}" ({1})'.format(
                            endpoint_name,
                            c.id)
                    if click.confirm(prompt):
                        ctx.invoke(
                            collection_delete,
                            collection_id=c.id,
                            force=True,
                            no_commit=True)
                        db.session.delete(c)
                        db.session.commit()
                    else:
                        all_collections_deleted = False
                if all_collections_deleted:
                    db.session.delete(uc)
                    db.session.commit()
                else:
                    all_user_credentials_deleted = False
            if all_user_credentials_deleted:
                db.session.delete(ss)
                click.echo('Deleted storage gateway {}'.format(ss.id))
            db.session.commit()


if __name__ == '__main__':
    storage_gateway_delete()
