import click

from ..app import app
from .constants import CONNECTOR_DISPLAY_NAMES
from globus.manager.api.models import (Connector, StorageGateway)
from globus.manager.version import __version__
from sqlalchemy.exc import OperationalError


@click.command(name='list', help='List storage gateways')
@click.help_option('--help', '-h')
@click.version_option(
    version=__version__,
    prog_name='globus-connect-server-config')
@click.option('--connector', '-c',
              type=click.Choice(CONNECTOR_DISPLAY_NAMES),
              help='List only storage gateways for this connector')
@click.option('--display-name', '-n',
              metavar='NAME',
              help='List only storage gateways that match NAME')
@click.argument('STORAGE_GATEWAY_ID', required=False)
def storage_gateway_list(connector, display_name, storage_gateway_id):
    with app.app_context():
        try:
            query_args = {}
            if connector is not None:
                st = Connector.query.filter_by(display_name=connector).one()
                query_args['connector_id'] = st.id
            if display_name is not None:
                query_args['display_name'] = display_name

            ss = StorageGateway.query.filter_by(**query_args).all()

            click.echo('ID | Storage Type | Display Name | Root')
            for s in ss:
                if (storage_gateway_id is not None
                        and s.id != storage_gateway_id):
                    continue
                click.echo('{0} | {1} | {2} | {3}'.format(
                    s.id,
                    s.connector.display_name,
                    s.display_name,
                    s.storage_policies['public'].get('root'),
                ))
        except OperationalError:
            click.echo('Permission denied')


if __name__ == '__main__':
    storage_gateway_list()
