from __future__ import absolute_import

import os
import pkgutil

from ..service_manager import ServiceManager


class GCSManager(object):
    '''
    Class to configure a GCS Manager service
    '''
    service_name = 'gcs_manager'

    def __init__(self, service_manager=ServiceManager, domain=None):
        self.domain = domain
        domain_cred_dir = os.path.join(
            os.path.expanduser('~gcsweb/etc/letsencrypt/live'),
            self.domain)
        self.service_manager = service_manager
        self.certificate_file = os.path.join(domain_cred_dir, 'cert.pem')
        self.key_file = os.path.join(domain_cred_dir, 'privkey.pem')
        self.chain_file = os.path.join(domain_cred_dir, 'chain.pem')

    def setup(self, force=False):
        self.service_manager.enable(self.service_name)
        self.service_manager.restart(self.service_name)

    def cleanup(self, force=False):
        self.service_manager.stop(self.service_name)
        self.service_manager.disable(self.service_name)

    def vhost_configuration(self):
        vhost_template = pkgutil.get_data(
            'globus_gcs.apache',
            'vhost-gcs-manager.conf').decode('ascii')

        return vhost_template.format(
            GCS_MANAGER_SERVER=self.domain,
            GCS_MANAGER_CERTIFICATE=self.certificate_file,
            GCS_MANAGER_KEY=self.key_file,
            GCS_MANAGER_CHAIN=self.chain_file)
