"""
Module to configure an apache server for SLES >= 12SP1 or
OpenSUSE >= Leap 42.2
"""
from __future__ import print_function, absolute_import

from subprocess import Popen, PIPE
import os

__apache_sites_available_file = "/etc/apache2/vhosts.d/{name}.conf.gcs"
__apache_sites_enabled_file = "/etc/apache2/vhosts.d/{name}.conf"

__gcs_enabled_mod = "/var/lib/globus-connect-server/enabled_mod_{name}"
__gcs_created_site = "/var/lib/globus-connect-server/created_site_{name}"
__gcs_enabled_site = "/var/lib/globus-connect-server/enabled_site_{name}"

service = "apache2"
required_modules = ['ssl']
required_confs = []


def site_add(name, site_config, force=False, enable=False):
    site_available = __apache_sites_available_file.format(name=name)
    created_site_path = __gcs_created_site.format(name=name)
    created_new_site = False

    if not os.path.exists(site_available):
        created_new_site = True

    with open(site_available, "w") as f:
        f.write(site_config)

    if force or created_new_site:
        open(created_site_path, "w").close()

    if enable:
        site_enable(name)


def site_remove(name, force=False):
    site_available = __apache_sites_available_file.format(name=name)
    created_site_path = __gcs_created_site.format(name=name)

    site_disable(name)

    if force or os.path.exists(created_site_path):
        os.remove(site_available)
        os.remove(created_site_path)


def module_enable(module):
    gcs_enabled_mod = __gcs_enabled_mod.format(name=module)
    modlist = Popen(
        ["/sbin/yast2", "http-server", "modules", "list"],
        stdin=None, stdout=PIPE, stderr=PIPE)

    (out, err) = modlist.communicate()
    already_enabled = False
    for l in err.split("\n"):
        if "\t" in l:
            status, module_name = l.strip().split("\t")
            if module == module_name and status == 'Enabled':
                already_enabled = True
                break

    if not already_enabled:
        enable_arg = "enable={name}".format(name=module)
        enabler = Popen(
            ["/sbin/yast2", "http-server", "modules", enable_arg],
            stdin=None)
        enabler.communicate()
        if enabler.returncode == 0:
            open(gcs_enabled_mod, "w").close()


def module_disable(module):
    gcs_enabled_mod = __gcs_enabled_mod.format(name=module)
    if os.path.exists(__gcs_enabled_mod):
        disable_arg = "disable={name}".format(name=module)
        disabler = Popen(
            ["/sbin/yast2", "http-server", "module", disable_arg],
            stdin=None)
        disabler.communicate()
        if disabler.returncode == 0:
            os.remove(gcs_enabled_mod)


def site_enable(name, force=False):
    available_site_path = __apache_sites_available_file.format(name=name)
    enabled_site_path = __apache_sites_enabled_file.format(name=name)
    gcs_enabled_site_path = __gcs_enabled_site.format(name=name)
    enabled_site = False

    if not os.path.exists(enabled_site_path):
        enabled_site = True

    if force and os.path.exists(enabled_site_path):
        os.remove(enabled_site_path)

    if not os.path.exists(enabled_site_path):
        os.symlink(available_site_path, enabled_site_path)

    if enabled_site:
        open(gcs_enabled_site_path, "w").close()


def site_disable(name):
    enabled_site_path = __apache_sites_enabled_file.format(name=name)
    gcs_enabled_site = __gcs_enabled_site.format(name=name)

    if os.path.exists(gcs_enabled_site):
        os.remove(enabled_site_path)
        os.remove(gcs_enabled_site)


def conf_enable(name, force=False):
    pass


def conf_disable(name):
    pass
