from __future__ import print_function, absolute_import

from .config_file import ConfigFile
from .sections import sections

__all__ = [
    'ConfigFile',
    'sections',
    'documentation',
    'default_config'
]


def default_config(include_private=False):
    result = []
    for s in sections:
        if not s.private or include_private:
            result.append(";" + "-" * 77)
            name = s.name

            namelen = len(name)
            pad = int((78 - namelen) / 2)
            if pad < 0:
                pad = 0
            result.append(";" + " " * pad + name)
            result.append(";" + "-" * 77)
            result.append("[%s]" % (name))

            for line in s.description.split("\n")[1:]:
                result.append(";" + line)
            for o in s.itervalues():
                if not o.private or include_private:
                    for line in o.description.split("\n"):
                        result.append(";" + line)
                    if o.default_value is not None:
                        result.append("{0} = {1}".format(
                            o.name, o.default_value))
                    elif not o.comment_out_if_none:
                        result.append("{0} = ".format(
                            o.name))
                    else:
                        result.append("; %s =" % (o.name))
    return "\n".join(result + [""])


def documentation(include_private=False):
    result = []
    result.extend([
        '= GLOBUS-CONNECT-SERVER(5)',
        '',
        '== NAME',
        'globus-connect-server - Configuration file for Globus '
        'Connect Server',
        '',
        '== DESCRIPTION',
        ''
        'This page describes the fields in the Globus Connect Server '
        'configuration file',
        ''])

    for s in sections:
        if not s.private or include_private:
            result.append("=== [" + s.name + "] Section\n")
            for line in s.description.split("\n")[1:]:
                result.append(line.strip())

            for n, o in s.iteritems():
                if not o.private or include_private:
                    result.append("==== " + n + "\n")
                    for line in o.description.split("\n"):
                        result.append(line.strip())
                    if o.default_value is not None:
                        result.append("  %s = %s" % (o.name, o.default_value))
                    result.append("")
    return "\n".join(result)
