from __future__ import print_function, absolute_import

import configparser
import copy
import os

from . import sections
from ..utils import HostInfo, log


class ConfigFile(object):
    __DEFAULT_CONFIG_FILE = "/etc/globus-connect-server.conf"

    def __init__(self, root="", config_file=__DEFAULT_CONFIG_FILE):
        defaults = copy.deepcopy(os.environ)
        defaults["HOSTNAME"] = HostInfo.public_name()
        if "SHORT_HOSTNAME" not in defaults:
            defaults["SHORT_HOSTNAME"] = defaults["HOSTNAME"].split(".")[0]
        if "USER" in defaults:
            del defaults["USER"]
        if "GLOBUS_USER" not in defaults:
            defaults["GLOBUS_USER"] = ""
        if "GLOBUS_PASSWORD" not in defaults:
            defaults["GLOBUS_PASSWORD"] = ""

        self.defaults = defaults
        self.parser = configparser.ConfigParser()
        self.config_file = config_file

        log.info("Parsing config file {}".format(config_file))

        if self.parser.read([config_file]) == []:
            raise configparser.ParsingError(config_file)
        self.sections = {}
        for s in sections.sections:
            new_s = copy.deepcopy(s)
            self.sections[new_s.name.lower()] = new_s
            setattr(self, new_s.name.replace(" ", ""), new_s)
        self.__parse(config_file)

    def __parse(self, config_file):
        """
        Validate the configuration file contents against the list of
        support options and store the values in the options
        """
        for parsed_section in self.parser.sections():
            # Make sure all sections are defined by the parser
            section_def = self.sections.get(parsed_section.lower())
            if section_def is None:
                raise Exception(
                    "Unknown config section {} in {}".format(
                        parsed_section, config_file))

        for section_def in self.sections.values():
            if not self.parser.has_section(section_def.name):
                self.parser.add_section(section_def.name)
            for n, o in section_def.iteritems():
                if not self.parser.has_option(section_def.name, n):
                    if o.default_value is not None:
                        self.parser.set(
                            section_def.name, n,
                            str(o.default_value) % self.defaults)
            for o in self.parser.options(section_def.name):
                val = self.parser.get(section_def.name, o, vars=self.defaults)
                section_def.set({o: val})
