class ConfigSection(object):
    def __init__(self, name, description, options, private=False):
        self.name = name
        self.description = description
        self.options_list = [o.name for o in options]
        self.options = {o.name.lower(): o for o in options}
        self.private = private
        for o in options:
            setattr(self, o.name.replace(" ", ""), o)

    def __iter__(self):
        return iter([o.lower() for o in self.options_list])

    def iterkeys(self):
        return self.__iter__()

    def iteritems(self):
        return iter([(o, self.options[o.lower()]) for o in self.options_list])

    def itervalues(self):
        return iter([self.options[o.lower()] for o in self.options_list])

    def get_default(self, option):
        option_def = self.options.get(option.lower())
        default_value = None
        if option_def is not None:
            default_value = option_def.default_value
        return default_value

    def merge(self, other_section):
        self.options_list.extend(other_section.options_list)
        self.options.update(other_section.options)
        for o in other_section.options.values():
            setattr(self, o.name.replace(" ", ""), o)

    def set(self, section_options):
        for opt, val in section_options.items():
            option_def = self.options.get(opt.lower())
            if option_def is None:
                raise Exception(
                    "Invalid configuration option [%s].%s"
                    % (self.name, opt))
            try:
                option_def.set(val)
            except Exception as e:
                raise Exception('Error parsing [{}].{}: {}'.format(
                    self.name, option_def.name, str(e)))
