"""
This configuration section configures how to contact Globus when
creating or modifying an endpoint.
"""

from __future__ import print_function, absolute_import

from .. import type_handlers
from ..config_option import ConfigOption
from ..config_section import ConfigSection

SECTION_NAME = "Globus"

PRODUCTION = "Production"
STAGING = "Staging"
TEST = "Test"
SANDBOX = "Sandbox"
PREVIEW = "Preview"

__INSTANCE_ENUMS = [
    PRODUCTION,
    STAGING,
    TEST,
    SANDBOX,
    PREVIEW,
]

OPTIONS = [
    ConfigOption(
        "ClientId",
        """
        The Client ID of the Globus Connect Server. This is created using the
        application located at https://auth.globus.org/v2/web/developers and
        selecting the New GCS option
        """,
        default_value=None,
        comment_out_if_none=False,
        type_handler=type_handlers.uuid_handler(),
    ),
    ConfigOption(
        "ClientSecret",
        """
        The Client Secret of the Globus Connect Server. This is created using
        the application located at https://auth.globus.org/v2/web/developers
        and selecting the New GCS option
        """,
        default_value=None,
        comment_out_if_none=False,
    ),
    ConfigOption(
        "Instance",
        """
        The name of the Globus instance to use. The default is the production
        instance.
        """,
        private=True,
        type_handler=type_handlers.enum_handler(__INSTANCE_ENUMS),
        default_value=__INSTANCE_ENUMS[0],
        comment_out_if_none=False,
    ),
]

section = ConfigSection(SECTION_NAME, __doc__, OPTIONS)
