'''
This section configures a GridFTP server. It can be processed on the
GridFTP server host to generate a GridFTP configuration file, and on
that or any other host to add a GridFTP server to an endpoint
'''

from __future__ import print_function, absolute_import

from .. import type_handlers
from ..config_option import ConfigOption
from ..config_section import ConfigSection

SECTION_NAME = 'GridFTP'

__RESTRICT_PATHS_RE = '(R|W|RW)~?(/[^,])*(,(R|W|RW)~?(/[^,]*))*'

OPTIONS = [
    ConfigOption(
        'IncomingPortRange',
        '''
        Port range to use for incoming connections.  The format is
        'startport,endport'. If not set, this will default to 50000,51000
        ''',
        type_handler=type_handlers.int_list_handler(1),
        default_value='50000, 51000'),
    ConfigOption(
        'OutgoingPortRange',
        '''
        Port range to use for outgoing connections.  The format is
        'startport,endport'.  Only use this if your firewall restricts outgoing
        ports and gridftp won't work otherwise. The default is not restrict
        outgoing TCP ports.
        ''',
        type_handler=type_handlers.int_list_handler(1)),
    ConfigOption(
        'DataInterface',
        '''
        Hostname or IP address of the interface to use for data connections.
        If not set in this file, then the default behavior is:
        - When run on an EC2 instance, the data interface will be
          automatically configured to use the public ipv4 address of the
          instance.
        - When run on a non-EC2 instance, if [Endpoint].ServerName is set, then
          that value is used. If this resolves to a private
          IP address, a warning will be issued.
        - Otherwise, this will not be set, and the gridftp server will tell
          clients to connect to the IP address that the control connection
          was established on.
        '''),
    ConfigOption(
        'RequireEncryption',
        '''
        Require an encrypted data connection for all transfers. Transfers
        attempted without encryption will result in error.
        ''',
        default_value=False,
        type_handler=type_handlers.boolean_handler()),
    ConfigOption(
        'AllowUDT',
        '''
        Allow the GridFTP server to use the UDT protocol for data channels.
        The default is False.
        ''',
        type_handler=type_handlers.boolean_handler(),
        default_value=False,
        private=True),
    ConfigOption(
        'ExtraArg',
        '''
        Any extra GridFTP configuration arguments. These are not checked
        by the globus-connect-server setup process.
        ''',
        private=True),
]

section = ConfigSection(SECTION_NAME, __doc__, OPTIONS)
