"""
This section configures the interaction with the Let's Encrypt service.
"""

from __future__ import print_function, absolute_import

from .. import type_handlers
from ..config_option import ConfigOption
from ..config_section import ConfigSection

SECTION_NAME = "LetsEncrypt"

OPTIONS = [
    ConfigOption(
        "Email",
        """
        The user must supply an email address for LetsEncrypt.
        """,
        comment_out_if_none=False,
    ),
    ConfigOption(
        "AgreeToS",
        """
        The user must explicitly agree to the Lets Encrypt Terms of Service.
        If not set to True, the globus-connect-server-setup scripts will
        provide a link to `https://letsencrypt.org/repository/` so user can
        view and acknowledge the ToS.
        """,
        default_value=False,
        type_handler=type_handlers.boolean_handler()),
    ConfigOption(
        "Staging",
        """
        If this site is testing deployment automation, use the Let's Encrypt
        staging credential service and deploy the fake root CAs.
        """,
        default_value=False,
        private=True,
        type_handler=type_handlers.boolean_handler()),
]

section = ConfigSection(SECTION_NAME, __doc__, OPTIONS)
