from __future__ import print_function, absolute_import

import re

from .string import ConfigTypeHandlerString


class ConfigTypeHandlerBoolean(ConfigTypeHandlerString):
    """
    Boolean configuration type handler. This handler will validate that
    the configuration value matches boolean string patterns
    """
    __BOOLEAN_TRUE = r"(1|true|yes|on)"
    __BOOLEAN_FALSE = r"(0|false|no|off)"

    def __init__(self):
        super(ConfigTypeHandlerBoolean, self).__init__()

    def parse(self, value):
        if value is None:
            return None
        unquoted = self.unquote(value)
        if re.match(self.__BOOLEAN_TRUE, unquoted, re.I) is not None:
            return True
        elif re.match(self.__BOOLEAN_FALSE, unquoted, re.I) is not None:
            return False
        else:
            raise Exception("Invalid value " + unquoted)
