from .string import ConfigTypeHandlerString


class ConfigTypeHandlerEnumList(ConfigTypeHandlerString):
    """
    Enum list configuration type handler. This handler will validate that
    the configuration value is a comma-separated list of values in the
    enumeration set.
    Whitespace boundaries for the values are discarded.
    """
    def __init__(self, values, maximum_splits=-1):
        super(ConfigTypeHandlerEnumList, self).__init__()
        self.values = values
        self.maximum_splits = maximum_splits

    def parse(self, value):
        if value is not None:
            split_value = [
                (v.strip())
                for v in self.unquote(value).split(",", self.maximum_splits)]
            for v in split_value:
                if v not in self.values:
                    raise Exception(
                        "Invalid value %s" % (v))
            return split_value
        return None
