from __future__ import absolute_import

import re


class ConfigTypeHandlerString(object):
    """
    Base configuration type handler. The only functionality it provides is to
    unquote configuration options
    """
    def __init__(self, value_match=None):
        self.valid = True
        self.value_match = value_match

    def parse(self, value):
        unquoted = self.unquote(value)
        if self.value_match is not None:
            if re.match(self.value_match, unquoted) is None:
                raise Exception(
                    "Value \"{v}\" does not match pattern \"{p}\".".format(
                        v=unquoted, p=self.value_match))
        return unquoted

    @classmethod
    def unquote(cls, value):
        if (value is not None
                and len(value) > 1
                and value[0] == '"'
                and value[-1] == '"'):
            value = value[1:-1]
        return value
