from .string import ConfigTypeHandlerString


class ConfigTypeHandlerStringList(ConfigTypeHandlerString):
    """
    String list configuration type handler. This handler will validate that
    the configuration value is a comma-separated list of string values.
    Whitespace within the string values are discarded.
    """
    def __init__(self, delimiter=",", maximum_splits=-1):
        self.maximum_splits = maximum_splits
        self.delimiter = delimiter
        super(ConfigTypeHandlerStringList, self).__init__()

    def parse(self, value):
        unquoted = self.unquote(value)

        if unquoted is None or unquoted == '':
            return []
        else:
            return [
                v.strip()
                for v in unquoted.split(self.delimiter, self.maximum_splits)]
