from __future__ import absolute_import

from .. import (
    GCSManager,
    WebServerManager
)

from ..service_manager import ServiceManager


class WebManager(object):
    """
    Class to configure a Web server with GCS-related services
    """
    def __init__(self, conf, web_server_manager=WebServerManager,
                 service_manager=ServiceManager,
                 services=[GCSManager]):
        self.web_server_manager = web_server_manager
        self.service_manager = ServiceManager

        self.services = []
        if services is not None:
            self.services.extend([
                service(self.web_server_manager, conf)
                for service in services])

    def setup(self, endpoint_id=None, force=False):
        for service in self.services:
            if isinstance(service, GCSManager):
                service.setup(force=force, endpoint_id=endpoint_id)
            else:
                service.setup(force=force)
        self.service_manager.restart(self.web_server_manager.service)

    def cleanup(self, force=False, stop=False):
        for service in self.services:
            service.cleanup(force=force)
        if stop:
            self.service_manager.stop(self.web_server_manager.service)
        else:
            self.service_manager.restart(self.web_server_manager.service)
