import logging
import os

from globus.manager.api.utils.services import get_transfer_client
from globus.manager.utils.platform_info import PlatformInfo
from globus.manager.api import make_app
from globus.manager.api.models import db, Configuration
from globus.manager.api.schemas import ma

os.environ['MANAGER_CONFIG'] = 'config/production.py'

application = make_app()
db.init_app(application)
ma.init_app(application)

# As a convenience, so we can use `flask.current_app`, load the
# Globus Auth client credentials and host endpoint id
# into the app's runtime config.
with application.app_context():
    globus_client_id = Configuration.query.filter_by(
        name='client_id').one().value
    globus_client_secret = Configuration.query.filter_by(
        name='client_secret').one().value
    host_endpoint_id = Configuration.query.filter_by(
        name='host_endpoint_id').one().value
    globus_environment = Configuration.query.filter_by(
        name='environment').one().value.lower()
    os.environ['GLOBUS_SDK_ENVIRONMENT'] = globus_environment

    if host_endpoint_id is not None:
        tc = get_transfer_client(environment=globus_environment)
        fingerprint = PlatformInfo().fingerprint()
        tc.update_endpoint(
            host_endpoint_id,
            {'gcs_private_version_json': fingerprint})


application.config['CLIENT_ID'] = globus_client_id
application.config['CLIENT_SECRET'] = globus_client_secret
application.config['HOST_ENDPOINT_ID'] = host_endpoint_id

@application.before_first_request
def setup_logging():
    if application.debug:
        application.logger.setLevel(logging.DEBUG)
    else:
        application.logger.setLevel(logging.INFO)
